summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorRoland McGrath <roland@redhat.com>1993-09-20 22:05:19 +0000
committerRoland McGrath <roland@redhat.com>1993-09-20 22:05:19 +0000
commitf8c3e52b0fcb14053cd71c9c0da4c3b14fbf157a (patch)
treed1dc24108e17544f7fd9beb469db03ba43622bd4
parent1775c102adc9414b9764c8c355c3b635c134e167 (diff)
downloadgunmake-f8c3e52b0fcb14053cd71c9c0da4c3b14fbf157a.tar.gz
Formerly main.c.~96~
-rw-r--r--main.c30
1 files changed, 16 insertions, 14 deletions
diff --git a/main.c b/main.c
index 7fb4026..07dc702 100644
--- a/main.c
+++ b/main.c
@@ -1649,20 +1649,22 @@ define_makeflags (all, makefile)
*p = '\0';
}
- (void) define_variable ("MAKEFLAGS", 9,
- /* On Sun, the value of MFLAGS starts with a `-' but
- the value of MAKEFLAGS lacks the `-'.
- Be compatible with this unless FLAGSTRING starts
- with a long option `--foo', since removing the
- first dash would result in the bogus `-foo'. */
- flagstring[1] == '-' ? flagstring : &flagstring[1],
- /* This used to use o_env, but that lost when a
- makefile defined MAKEFLAGS. Makefiles set
- MAKEFLAGS to add switches, but we still want
- to redefine its value with the full set of
- switches. Of course, an override or command
- definition will still take precedence. */
- o_file, 0);
+ define_variable ("MAKEFLAGS", 9,
+ /* On Sun, the value of MFLAGS starts with a `-' but
+ the value of MAKEFLAGS lacks the `-'.
+ Be compatible with this unless FLAGSTRING starts
+ with a long option `--foo', since removing the
+ first dash would result in the bogus `-foo'. */
+ flagstring[1] == '-' ? flagstring : &flagstring[1],
+ /* This used to use o_env, but that lost when a
+ makefile defined MAKEFLAGS. Makefiles set
+ MAKEFLAGS to add switches, but we still want
+ to redefine its value with the full set of
+ switches. Of course, an override or command
+ definition will still take precedence. */
+ o_file, 0)
+ /* Always export MAKEFLAGS. */
+ ->export = v_export;
/* Since MFLAGS is not parsed for flags, there is no reason to
override any makefile redefinition. */
(void) define_variable ("MFLAGS", 6, flagstring, o_env, 0);